@@ -10,7 +10,7 @@ import iris
 
 from inspect import signature
 
-from dacite import from_dict
+from dacite import from_dict, Config
 
 from grongier.pex._common import _Common
 
@@ -153,8 +153,12 @@ class _BusinessHost(_Common):
             return self._serialize_message(message)
         elif (message is not None and self._is_pickle_message_instance(message)):
             return self._serialize_pickle_message(message)
-        else:
+        elif (message is not None and self._is_iris_object_instance(message)):
             return message
+        else:
+            # todo : decorator takes care of all the parameters, so this should never happen
+            return message
+            #raise TypeError("The message must be an instance of a class that is a subclass of Message or IRISObject %Persistent class.")
 
     def _serialize_message(self,message):
         """ Converts a python dataclass message into an iris grongier.pex.message.
@@ -296,7 +300,7 @@ class _BusinessHost(_Common):
         :param dikt: the dictionary to convert to a dataclass
         :return: A dataclass object with the fields of the dataclass and the fields of the dictionary.
         """
-        ret = from_dict(klass, dikt)
+        ret = from_dict(klass, dikt, Config(check_types=False))
         
         try:
             fieldtypes = klass.__annotations__
